local gr = love.graphics

function love.load()
	gr.setBackgroundColor( 0.4, 0.4, 0.4 )
	id = love.image.newImageData( 'pipes.png' )
	iw = id:getHeight()
	pipe = {}
	for i = 1, 12 do pipe[i] = crop( id, iw*(i-1), 0, iw, iw ) end
	sz = 0.7*iw							-- pipe segment size (sz,sz)
	grid = Grid.load( 1, 11, 9 )	-- fill grid with blanks
	selected = 1						-- no pipe
	end

function love.update( dt )
	Grid.check( 11, 9 )				-- see if pipe should be added
	end

function love.draw()
	if test then Grid.draw( 0, 0, sz, sz, 11, 9 ) end
	local sz2 = 45
	gr.setColor( 0.2, 0.7, .9 )
	gr.rectangle( 'fill', 800-sz2, (selected-1)*sz2+20, sz2, sz2 )
	for i = 0, #pipe-1 do
		px, py = 800-sz2, i*sz2+20
		gr.rectangle( 'line', px, py, sz2, sz2 )
		if pointInBox( {love.mouse.getPosition()}, {px, py, sz2, sz2 } ) then
			gr.setColor( 0.9, 0.8, 1 )
			selected = math.floor( py/sz2+1 )	-- pipe number selected
			else
			gr.setColor( 1, 1, 1 )
			end
		gr.draw( pipe[i+1], px, py, 0, sz2/iw, sz2/iw )
		end
	Grid.show( grid )
	end

function love.keypressed( key )
	if key == 'escape' then love.event.push( 'quit' )	end
	if key == 't' then test = not test end
	if key == 'left'  then sz = sz -5  end
	if key == 'right' then sz = sz +5  end
	end

Grid = {
	check = function( nx, ny )
		if love.mouse.isDown(1) then	-- no need to check if mouse not down
			for y = 1,ny do
				for x = 1, nx do
					if pointInBox({love.mouse.getPosition()},{sz*(x-1),sz*(y-1),sz,sz}) then
						grid[y][x] = selected
						end
					end
				end
			end
		end,

	draw = function( x, y, w, h, nx, ny )
		gr.setColor(1,1,1)
		for j = 0, ny-1 do
			for i = 0, nx-1 do
				gr.rectangle( 'line', x+i*w, y+j*h, w, h )
				end
			end
		end,
	load = function( v, nx, ny )
		local g = {}
		for y = 1, ny do g[y] = {}
			for x = 1, nx do g[y][x] = v
				end
			end
		return g
		end,
	show = function( g )
		gr.setColor(1,1,1)
		for y = 1, #g do
			for x = 1, #g[y] do
				gr.draw( pipe[g[y][x]], sz*(x-1), (y-1)*sz, 0, sz/iw, sz/iw )
				end
			end
		end
	}

pointInBox = function( pt, bx )
	return pt[1]>=bx[1] and pt[1]<=bx[1]+bx[3] and pt[2]>=bx[2] and pt[2]<=bx[2]+bx[4]
	end

crop = function( sid, x, y, w, h )	-- imagedata, source location for crop and dimensions of crop
	local did = love.image.newImageData( w, h )
	did:paste( sid, 0, 0, x, y, w, h )		-- paste imagedata into imagedata
	return gr.newImage( did )					-- return image
	end